@@ -1,6 +1,6 @@
 from django.core.urlresolvers import reverse
 from django.db.models.fields.related import ReverseSingleRelatedObjectDescriptor
-from django.utils.encoding import StrAndUnicode
+from django.utils.encoding import python_2_unicode_compatible
 from django.utils.safestring import mark_safe
 
 from viewsets.mixins.base import SessionDataMixin
@@ -9,7 +9,8 @@ from django.db.models.fields import FieldDoesNotExist
 from django.utils.html import escapejs, escape
 
 
-class Header(StrAndUnicode):
+@python_2_unicode_compatible
+class Header(object):
 
     def __init__(self, title, sort_field=None, sorting=0, link=None, sort_name="sort"):
         self.title = title
@@ -29,10 +30,9 @@ class Header(StrAndUnicode):
                 retval = '<a href="?%s=">%s <i class="glyphicon glyphicon-chevron-up"></i></a>' % (self.sort_name, self.title)
         else:
             retval = self.title
+        return retval
 
-        return mark_safe(retval)
-
-    def __unicode__(self):
+    def __str__(self):
         return self.link_tag
 
 
@@ -61,8 +61,9 @@ class SortMixin(SessionDataMixin):
         if queryset is None:
             queryset = super(SortMixin, self).get_queryset(queryset)
 
+        sort_fields = self.ordering
         sort_terms = self.get_sort_fields()
-        if sort_terms:
+        if sort_terms and sort_terms == ":default:":
             allowed_fields = list(self.get_allowed_sort_fields(queryset.model))
 
             sort_fields = []
@@ -77,8 +78,6 @@ class SortMixin(SessionDataMixin):
 
                 if sort in allowed_fields:
                     sort_fields.append(desc and "-" + sort or sort)
-        else:
-            sort_fields = self.ordering
 
         if sort_fields:
             self.sorting_fields = sort_fields
